# Takopi User Guide (moved)

This guide has been reorganized into smaller Diátaxis pages.

## Start here

- [Install & onboard](tutorials/install.md)
- [First run](tutorials/first-run.md)

## Common tasks

- [Switch engines](how-to/switch-engines.md)
- [Projects](how-to/projects.md)
- [Worktrees](how-to/worktrees.md)
- [Route by chat](how-to/route-by-chat.md)
- [Topics](how-to/topics.md)
- [Voice notes](how-to/voice-notes.md)
- [File transfer](how-to/file-transfer.md)
- [Schedule tasks](how-to/schedule-tasks.md)
- [Troubleshooting](how-to/troubleshooting.md)

## Reference

- [Configuration](reference/config.md)
- [Commands & directives](reference/commands-and-directives.md)
- [Context resolution](reference/context-resolution.md)
